@@ -1,7 +1,13 @@
+"""
+mixcoatl.resource
+------------------
+
+"""
 from mixcoatl.settings.load_settings import settings
 import mixcoatl.auth as auth
 import requests as r
 from mixcoatl.decorators.lazy import lazy_property
+from mixcoatl.utils import camel_keys
 
 class Resource(object):
     """The base class for all resources returned from an enStratus API call
@@ -36,22 +42,34 @@ class Resource(object):
             The Resource object, while looking much like a `dict`, is not a `dict` proper.
             If you need an actual `dict`, call `to_dict()` on your instance.
     """
-    
-    #: The request path of the resource
-    path = None
-    #: The top-level grouping of a resource in the API response
-    collection_name = None
-    #: The unique identifier of an individual resource
-    primary_key = None
 
-    def __init__(self, base_path=None, request_details = 'extended'):
+    #: The base request path of the resource
+    PATH = None
+    #: The top-level grouping of a resource in the API response
+    COLLECTION_NAME = None
+    #: The unique identifier of an individual resource
+    PRIMARY_KEY = None
+
+    def __init__(self, base_path=None, request_details = 'extended', **kwargs):
+
         if base_path is None:
             try:
-                self.__path = self.__class__.path
+                self.__path = self.__class__.PATH
             except:
                 raise AttributeError('you must override base_path')
         else:
             self.__path = base_path
+
+        if 'request_details' in kwargs:
+            self.__request_details = kwargs['request_details']
+            del kwargs['request_details']
+        else:
+            self.__request_details = 'extended'
+
+        if 'params' in kwargs:
+            self.__params = kwargs['params']
+        else:
+            self.__params = {}
         self.__last_request = None
         self.__last_error = None
         self.__current_job = None
@@ -59,8 +77,9 @@ class Resource(object):
         self.pending_changes = {}
 
     def __props(self):
-        p = [k for k,v in self.__class__.__dict__.items() if type(v) in [lazy_property, property]]
-        rp = ['last_error', 'path', 'last_request', 'current_job']
+        """List of properties and lazy properties for a given resource"""
+        p = [k for k, v in self.__class__.__dict__.items() if type(v) in [lazy_property, property]]
+        rp = ['last_error', 'path', 'last_request', 'current_job', 'request_details']
         return p + rp
 
 
@@ -124,16 +143,24 @@ class Resource(object):
     def current_job(self, cj):
         self.__current_job = cj
 
+    @property
+    def params(self):
+        return self.__params
+
+    @params.setter
+    def params(self, p):
+        self.__params = p
+
     def load(self):
         """(Re)load the current object's attributes from an API call"""
         from mixcoatl.utils import uncamel_keys
         reserved_words = ['type']
-        p = self.path+"/"+str(getattr(self, self.__class__.primary_key))
+        p = self.PATH+"/"+str(getattr(self, self.__class__.PRIMARY_KEY))
 
         #self.request_details = 'extended'
-        s = self.get(p)
+        s = self.get(p, params=camel_keys(self.params))
         if self.last_error is None:
-            scope = uncamel_keys(s[self.__class__.collection_name][0])
+            scope = uncamel_keys(s[self.__class__.COLLECTION_NAME][0])
             for k in scope.keys():
                 if k in reserved_words:
                     the_key = 'e_'+k
@@ -163,7 +190,7 @@ class Resource(object):
         headers = {'x-esauth-access': sig['access_key'],
         'x-esauth-timestamp': str(sig['timestamp']),
         'x-esauth-signature': str(sig['signature']),
-        'x-es-details': self.__request_details,
+        'x-es-details': self.request_details,
         'Accept': 'application/json',
         'User-Agent': sig['ua']}
 
@@ -173,7 +200,11 @@ class Resource(object):
         self.last_error = None
         self.last_request = results
         if results.status_code in failures:
-            self.last_error = results.json()
+            try:
+                err = results.json()
+                self.last_error = err['error']['message']
+            except ValueError:
+                self.last_error = results.content
             return self.last_error
 
         if method == 'GET':
@@ -182,11 +213,19 @@ class Resource(object):
                 self.last_error = None
                 return results.json()
             except r.exceptions.HTTPError:
-                self.last_error = results.json()
+                try:
+                    err = results.json()
+                    self.last_error = err['error']['message']
+                except ValueError:
+                    self.last_error = results.content
                 return False
         if method == 'DELETE':
-            if results.status_code !=204:
-                self.last_error = results.json()
+            if results.status_code != 204:
+                try:
+                    err = results.json()
+                    self.last_error = err['error']['message']
+                except ValueError:
+                    self.last_error = results.content
                 return False
             else:
                 return True
@@ -197,15 +236,23 @@ class Resource(object):
             elif results.status_code == 204:
                 return True
             else:
-                self.last_error = results.json()
-                return self.last_error
+                try:
+                    err = results.json()
+                    self.last_error = err['error']['message']
+                except ValueError:
+                    self.last_error = results.content
+                return False
         if method == 'POST':
-            if results.status_code in [201,202]:
+            if results.status_code in [201, 202]:
                 if results.status_code == 202:
                     self.current_job = results.json()['jobs'][0]['jobId']
                 return results.json()
             else:
-                self.last_error = results.json()
+                try:
+                    err = results.json()
+                    self.last_error = err['error']['message']
+                except ValueError:
+                    self.last_error = results.content
                 return False
 
     def set_path(self, path=None):
@@ -243,6 +290,8 @@ class Resource(object):
         """The `dict` representation of the current resource"""
         return eval(repr(self))
 
-    def track_change(self, var, new_value):
-        prev = getattr(self, var)
-        self.pending_changes[var] = {'old': prev, 'new':new_value}
+    def track_change(self, var, prev, new):
+        if prev == new:
+            pass
+        else:
+            self.pending_changes[var] = {'old': prev, 'new':new}
